import { request } from 'umi';
import { downloadBlob } from './download';

function requestInterceptor(url, options) {
  const headers = options.headers || {};
  const token = localStorage.getItem('token')
    ? { 'X-Authorization-JWT': localStorage.getItem('token') }
    : {};
  const prefix =
    process.env.NODE_ENV === 'production' ? 'http://sgl-v2.njyunzhi.com/api/admin' : '/api/admin';

  return {
    url: `${prefix}${url}`,
    options: {
      ...options,
      headers: {
        ...headers,
        ...token,
      },
    },
  };
}

async function responseInterceptor(response) {
  const contextType = response.headers.get('content-type');
  if (contextType.indexOf('json') > -1) {
    const result = await response.clone().json();
    if (result?.token || result?.data?.token) {
      localStorage.setItem('token', result?.token || result?.data?.token);
    }

    if (result.code === 1000) {
      return result;
    }
    return Promise.reject(result);
  }

  if (contextType.indexOf('application/vnd.ms-excel') > -1) {
    const data = await response.clone().blob();
    const content = response.headers.get('content-disposition');
    const fileName = content.replace('attachment;filename=', '');
    downloadBlob(data, decodeURIComponent(fileName));
  }

  return response;
}

// https://umijs.org/plugins/plugin-request
export const requestConfig = {
  errorConfig: {
    adaptor: (resData) => {
      return {
        ...resData,
        success: resData.code === 1000,
        errorMessage: resData.message,
        showType: 0, // 静默处理错误
      };
    },
  },
  requestInterceptors: [requestInterceptor],
  responseInterceptors: [responseInterceptor],
};

export default (...args) => request(...args).then((r) => r.data);

export function queryTable(apiRequest) {
  return function (params) {
    return apiRequest({
      ...params,
      pageNum: params.current,
    })
      .then((res) => {
        return {
          data: res.records,
          success: true,
          total: res.total,
        };
      })
      .catch((err) => {
        return {
          success: false,
        };
      });
  };
}
